#!/bin/sh
#

. #ENVPT3#/bin/protopenv

TMPDIR=${TMPDIR-/tmp}
LOGDIR=${LOGDIR-/tmp}

# tweak healthcheck behavior
#

HCMONINT=${2-60}		# interval (in seconds) between monitoring samples, internal min 30, max 900 default 300
HCSAMPLES=${3-30}		# number of samples to monitor, internal min 1, default 5
LGLOOKBK=${4-7}			# number of days to look back in the .lg file, internal min 1, default 7

export HCMONINT HCSAMPLES LGLOOKBK

cd ${PROTOP}

if [ ! -d ${TMPDIR} ]
then
        mkdir ${TMPDIR}
fi

if [ ! -d ${LOGDIR} ]
then
	mkdir ${LOGDIR}
fi

errmsg()
{
	echo ""
	echo "${1}"
	echo ""
}

# P1 is a "friendly name" in etc/dblist.cfg

P1=${1}

if [ -z "${P1}" ]
then
        errmsg "usage: ${0} friendlyName [monint [numsamples [lglookback]]]"
	errmsg "Please at least specify a friendly name in etc/dblist.cfg."
	exit 1
fi

# Check etc/dblist.cfg for a matching "friendly name"
#

if [ -f ${PROTOP}/etc/dblist.cfg ]			# search using "pipe" as the delimiter
then
	XDB=$(grep "^${P1}|" ${PROTOP}/etc/dblist.cfg | awk -F"|" '{print $2}' 2>/dev/null)
fi

# if XDB has a value then we found a friendly name and the path is in XDB #

if [ -z "${XDB}" ]					# no friendly name?
then
	errmsg "Friendly name ${P1} does not exist."
	exit 1
else
	PARAM='-param '"${P1}"				# pass the friendly name into protop.p
fi

# chain togther .pf files if they exist
#
# 	etc/type.pf
# 	etc/friendlyName.pf
#

if [ -f ${PROTOP}/etc/dblist.cfg ]
then
	XTYPE=`grep "^${P1}|" ${PROTOP}/etc/dblist.cfg | awk -F"|" '{print $6}' 2>/dev/null`
	if [ ! -z "${XTYPE}" ]
	then
		if [ -f etc/${XTYPE}.pf ]
		then
			PFLIST="${PFLIST} -pf etc/${XTYPE}.pf"
		fi
	fi
fi

if [ -f ${PROTOP}/etc/${P1}.pf ]
then
	PFLIST="${PFLIST} -pf etc/${P1}.pf"
fi

rm -f ${LOGDIR}/hc.${P1}.log

${DLC}/bin/_progres -b -p util/healthcheck.p ${XDB} ${PARAM} ${PFLIST} -T ${TMPDIR} ${ERRSTACK} -clientlog ${TMPDIR}/hc.${P1}.debug >> $LOGDIR/healthcheck.log 2>&1
