#!/bin/bash
#
# Similar to:
#
#	dd if=/dev/zero of=./test.out bs=16k count=6144 oflag=dsync
#
# the "dd" command might be helpful in explaining to non-Progress people that IO issues are "not Progress".
#
#
# **********************************************************************
# **********************************************************************
# 
#     IF YOUR OS LACKS /usr/bin/time and your shell does not support
#     time -p this script will not work correctly as a portal data
#     source.
#
#     Note: /bin/bash rather than the usual /bin/sh above
#
#     The implementation of "time -p" varies -- for many, but not all,
#     shells it is built-in.  For others we must use /usr/bin/time and
#     hope for the best.
# 
#     The "dash" shell is an example.
# 
# **********************************************************************
# **********************************************************************
#
#
# minimum acceptable result for a medium demand server is 10MB/sec -- or 9 seconds
#   4 or 5 seconds is better
#   3 or less is "meh, ok, you don't need to throw the storage subsystem into a dumpster quite yet"
#   1 or 2 is really where you want to be in 2019

. #ENVPT3#/bin/protopenv

LOGDIR=${LOGDIR-/tmp}

ZEXTENDSYNCIO=""
PROVERSION=`cat $DLC/version | awk '{print $3}'`                            # e.g. 11.7.15
PROMAJORMINOR=`expr substr "${PROVERSION}" 1 4`                             # e.g. 11.7
PROMAJOR=`cat $DLC/version | awk '{print $3}' | awk -F. '{print $1}'`       # e.g. 11


# a default SYNCIODIR can be set in bin/localenv
#

if [ ! -z "${SYNCIODIR}" ]
then
	if [ -d ${SYNCIODIR} ]
	then
		cd ${SYNCIODIR}
	fi
fi

# or you can pass it as a parameter
#

if [ ! -z "${1}" ]
then
	if [ -d ${1} ]
	then
		cd ${1}
	fi
fi

# perhaps this should move to localenv?
#

if [ -f /usr/bin/time ]
then
	# TIMECMD="/usr/bin/time -p"
	TIMECMD="bin"
else
	# TIMECMD="time -p"
	TIMECMD="builtin"
fi

# batch or interactive?
#

tty > /dev/null 2>&1
ISATTY=$?

if [ "${ISATTY}" = "0" ]
then
	echo "Please wait... "
	echo ""
fi


PWD=`pwd`

# verify that there is not an existing sports db
#
# if it exists it may not have been properly cleaned up or there might be a conflicting usage - either way we want to be cautious
#

if [ -f sports.db  ]
then
	echo "sports already exists at ${PWD}, please check configuration!"
	exit
fi


# enough prep, let's get to work...
#

echo "y" | prodb sports sports > /dev/null 2>&1

proutil sports -C truncate bi -bi 16384 -biblocksize 16 > /dev/null 2>&1	# bigrow uses 16k blocks regardless of -biblocksize, but set it anyway
if [ $? != 0 ]
then
	echo "Something went horribly wrong. Cannot measure synchronous IO write time to ${PWD}.  Error: $?"
	exit
fi

# for oe 11.3+ we need to add -zextendSyncIO
#

case "${PROMAJOR}" in

	"9"|"10")
    ;;

  "11")
    if [ "${PROMAJORMINOR}" != "11.0" -a "${PROMAJORMINOR}" != "11.1" -a "${PROMAJORMINOR}" != "11.2" ]
    then
      # 11.3.x - 11.7.x
      ZEXTENDSYNCIO="-zextendSyncIO"
    fi
    ;;

	*)
		ZEXTENDSYNCIO="-zextendSyncIO"
    ;;

esac

PROCMD="proutil sports -C bigrow 2 ${ZEXTENDSYNCIO}"

# time the execution of bigrow
#

case ${TIMECMD} in
	"builtin")
		echo `date "+%Y/%m/%d %T " ; ( time -p ${PROCMD} ) 2>&1 | grep -i real ; echo " ${PWD}"` | tee -a ${LOGDIR}/syncio.log
		;;
	"bin")
		echo `date "+%Y/%m/%d %T " ; ( /usr/bin/time -p ${PROCMD} ) 2>&1 | grep -i real ; echo " ${PWD}"` | tee -a ${LOGDIR}/syncio.log
		;;
	*)
		echo `date "+%Y/%m/%d %T " ; echo 'unknown "time" command'` | tee -a ${LOGDIR}/syncio.log
		;;
esac

if [ "${ISATTY}" = "0" ]
then
	echo '>10 seconds = pathetic, where did you get this junk? a 5.25" floppy disk would probably be an improvement.'
	echo "  9 seconds =  10MB/sec -- barely acceptable, but your users are probably plotting an uprising."
	echo "  5 seconds =  20MB/sec -- you should be looking for better storage, there are lots of inexpensive options that will beat this turkey."
	echo "  3 seconds =  30MB/sec -- meh, ok, you don't need to throw the storage subsystem into a dumpster quite yet.  but start thinking about it."
	echo '  1 second  = 100MB/sec -- excellent!'
	echo ""
#

fi

# clean up the temporary sports db
#

echo "y" | prodel sports > /dev/null 2>&1
rm -f sports.st

# time -p dd if=/dev/zero of=./test.out bs=16k count=6144 oflag=dsync
