#!/bin/sh

. #ENVPT3#/bin/protopenv

MNAME="util/zippyng.p"

cd ${PROTOP}

if [ ! -d ${TMPDIR} ]
then
        mkdir ${TMPDIR}
fi

if [ ! -d ${LOGDIR} ]
then
        mkdir ${LOGDIR}
fi

errmsg()
{
	echo ""
	echo "${1}"
	echo ""
}

if [ -z "${1}" ]
then
	errmsg "usage: ${0} friendlyName shm|lh|cs [host] [port]"
	exit
fi

# save ${1} and shift the command args so that we can easily pass along $2 etc
#
# FRNAME is a "friendly name" in etc/dblist.cfg
#

FRNAME=${1}
P1=${1}

if [ -z "${FRNAME}" ]
then
	errmsg "Please specify a friendly name in etc/dblist.cfg."
	exit
fi
shift

DBPATH=
getDBPATH ${FRNAME}

# if DBPATH has a value then we found a friendly name and the path is in DBPATH
#

if [ ! -z "${DBPATH}" ]					# friendly name!
then
	PARAM='-param '"${FRNAME}"			# pass the friendly name into protop.p
else
	errmsg "Please specify a friendly name in etc/dblist.cfg."
	exit
fi

# we need a monitor type
#

MONTYPE=${1}
echo "~shm,~lh,~cs," | grep "~${MONTYPE}," > /dev/null

if [ $? != 0 ]
then
	errmsg 'Please specify a monitor type of "shm", "lh" or "cs".'
	exit
fi
shift

FRNAME=${FRNAME}.${MONTYPE}

if [ "${MONTYPE}" = "lh" ]
then

	if [ -z "${1}" ]
	then
		errmsg 'Please specify a port to connect to.'
		exit
	fi

	XTRA="-S ${1}"
	# echo $XTRA

fi

if [ "${MONTYPE}" = "cs" ]
then

	if [ -z "${2}" ]
	then
		errmsg 'Please specify a hostname and port to connect to.'
		exit
	fi

	if [ -z "${1}" ]
	then
		errmsg 'Please specify a hostname and port to connect to.'
		exit
	fi

	XTRA="-H ${1} -S ${2}"
	# echo $XTRA

fi

# chain togther .pf files if they exist
#
#       etc/type.pf
#       etc/friendlyName.pf
#

if [ -f ${PROTOP}/etc/dblist.cfg ]
then
        XTYPE=`grep "^${P1}|" ${PROTOP}/etc/dblist.cfg | awk -F"|" '{print $6}' 2>/dev/null`
        if [ ! -z "${XTYPE}" ]
        then
                if [ -f etc/${XTYPE}.pf ]
                then
                        PFLIST="${PFLIST} -pf etc/${XTYPE}.pf"
                fi
        fi
fi

if [ -f ${PROTOP}/etc/${P1}.pf ]
then
        PFLIST="${PFLIST} -pf etc/${P1}.pf"
fi



# ok, we are ready to launch!
#

# _progres -b -p util/zippyng.p friendlyName -param friendlyName.cs 

# FRNAME = FRNAME.MONTYPE (see above)
#

X=`ps -ef | grep "util/zippyng.p " | grep _progres | grep "param ${FRNAME} "`

if [ ! -z "${X}" ]
then
	exit
fi

if [ -f ${DBPATH}.db ] || [ "${MONTYPE}" = "cs" ]
then

	if [  "${MONTYPE}" = "cs" ]
	then

		# Note: FRNAME includes the ".cs", you will need to replace SERVER: and /logdir with appropriate values
		#
		# set this in bin/zipenv -- it is documented here for reference
		#
		# export ZIPSYNC="rsync -avzqe ssh ${LOGDIR}/zippyng.${FRNAME}.log SERVER:/logdir 1>${TMPDIR}/zippyng.${FRNAME}.err 2>&1"

		if [ -f ${PROTOP}/bin/zipenv ]
		then
			. ${PROTOP}/bin/zipenv
		fi

		XDB=`basename ${DBPATH}`
		${DLC}/bin/_progres -b -p ${MNAME} ${XDB}    -param ${FRNAME} ${PFLIST} -T ${TMPDIR} ${XTRA} $ZIPPYMm >> ${TMPDIR}/zippyng.${FRNAME}.err 2> ${TMPDIR}/zippyng.${FRNAME}.err &

	else
		${DLC}/bin/_progres -b -p ${MNAME} ${DBPATH} -param ${FRNAME} ${PFLIST} -T ${TMPDIR} ${XTRA} $ZIPPYMm >> ${TMPDIR}/zippyng.${FRNAME}.err 2> ${TMPDIR}/zippyng.${FRNAME}.err &
	fi

else
	errmsg "${DBPATH}.db does not exist."
fi
